/* Feature Area css
============================================================================================ */

.single-feature {
    padding: 30px 15px;
    text-align: center;
    border: 1px solid #eff2f3;
    margin-bottom: 50px;
    h3 {
        font-size: 15px;
        font-weight: 500;
        text-transform: uppercase;
        margin-top: 25px;
    }
    .title {
        i {
            color: #4a4a4a;
            font-weight: 500;
            font-size: 24px;
            display: inline-block;
        }
    }
    p {
        margin-bottom: 0px;
        margin-top: 10px;
    }
}